import { defineStore } from "pinia";
import { getStuInfo, fetchOpenId, logout, wxUnbind } from "@/api/user";
import router from "@/router/index";

const useUserStore = defineStore("user", {
  persist: {
    storage: localStorage,
    paths: ["loginInfo", "stuInfo", "openId"],
  },
  state: () => ({ loginInfo: null, stuInfo: null, openId: "" }),
  actions: {
    setState(data) {
      this.$patch(data);
    },
    setLoginInfo(data) {
      this.loginInfo = data;
    },
    requestStuInfo() {
      getStuInfo().then((res) => {
        this.stuInfo = res;
      });
    },
    async requestOpenId(code) {
      let res = await fetchOpenId(code).catch(() => {});
      if (res) {
        let openid = typeof res === "string" ? res : res?.openid;
        this.openId = openid;
        return openid;
      } else {
        return false;
      }
    },
    async logout() {
      let res = await wxUnbind().catch(() => {});
      logout().then(() => {
        router.replace("/login");
      });
    },
    resetUser() {
      this.$reset();
    },
  },
});

export default useUserStore;
